==> ws-v3.70.10-src.tar.gz: ws-v3.70-10/include/WSCvballoonHelp.h <==
//
// Copyright (C) 1999-2004 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#ifndef WSCVBALLOONHELP_H
#define WSCVBALLOONHELP_H

#include <WScom.h>
#include <WSCngbase.h>
#include <WSDimage.h>
#define WSCvballoonHelp_VER  1000

class WSCvballoonHelp   :public WSCngbase{
  protected:
    char* _client; 
    char* _label_string; 

    WSMFpropertyDef(WSNclient,      char*,      _client);
    WSMFpropertyDef(WSNlabelString, char*,      _label_string);
    void _register();
  public:

    WSCvballoonHelp(WSCbase* base, char* name);
    virtual ~WSCvballoonHelp();
    virtual char* getDefaultProperty();

    WSMFguiClassDef(WSCvballoonHelp,WSCngbase);
    WSMFversionDef(WSCvballoonHelp);
};

#endif //WSCVBALLOONHELP_H

==> ws-v3.80.5-src.tar.gz: ws-v3.80-5/include/WSCvballoonHelp.h <==
//
// Copyright (C) 1999-2004 WideStudio Development Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of WideStudio Development Team
// shall not be used in advertising or otherwise to promote the sale, use or
// other dealings in this Software without prior written authorization from
// WideStudio Development Team.

#ifndef WSCVBALLOONHELP_H
#define WSCVBALLOONHELP_H

#include <WScom.h>
#include <WSCngbase.h>
#include <WSDimage.h>
#define WSCvballoonHelp_VER  1000

class WSCvballoonHelp   :public WSCngbase{
  protected:
    char* _client; 
    char* _label_string; 

    WSMFpropertyDef(WSNclient,      char*,      _client);
    WSMFpropertyDef(WSNlabelString, char*,      _label_string);

    WSDLEX32 void _register();
  public:

    WSDLEX32 WSCvballoonHelp(WSCbase* base, char* name);
    WSDLEX32 virtual ~WSCvballoonHelp();
    WSDLEX32 virtual char* getDefaultProperty();

    WSMFguiClassDef(WSCvballoonHelp,WSCngbase);
    WSMFversionDef(WSCvballoonHelp);
};

#endif //WSCVBALLOONHELP_H
